@@ -1,24 +1,28 @@
 from setuptools import setup, find_packages
 
 setup(
-    name = "cctbx",
-    version = "2021.12",
-    author = "cctbx",
-    author_email = "cctbx@cci.lbl.gov",
-    description = "cctbx",
-    license = "CCTBX 2.0",
-    keywords = "crystallography",
-    url = "http://cctbx.sourceforge.net/",
+    name="cctbx",
+    version="2023.12",
+    author="cctbx",
+    author_email="cctbx@cci.lbl.gov",
+    description="cctbx",
+    license="CCTBX 2.0",
+    keywords="crystallography",
+    url="http://cctbx.sourceforge.net/",
     packages=find_packages(
         where=".",
-        exclude=["boost", "crys3d", "cudatbx", "gltbx", "prime", "xfel"],
+        exclude=["boost", "crys3d", "cudatbx", "prime", "xfel"],
     ),
     install_requires=[
+        "hdf5plugin",
         "h5py",
         "numpy",
         "matplotlib",
         # "_pycbf",
         "mrcfile",
+        "natsort",
+        "nxmx",
+        "ordered_set",
         "pint",
         "procrunner",
         "pymol",
